<?php
class BabelBridge extends BridgeAbstract {
	const NAME = 'Babel Bridge';
	const URI = 'https://babel.ua';
	const DESCRIPTION = 'Collect news, texts and podcasts from Babel.ua';
	const MAINTAINER = 'pfactum';
	const PARAMETERS = [
		[
			'language' => [
				'name' => 'Language',
				'type' => 'list',
				'values' => [
					'Ukrainian' => 'ua',
					'English' => 'en',
				],
			],
			'content' => [
				'name' => 'Content',
				'type' => 'list',
				'values' => [
					'Everything' => 'everything',
					'News' => 'news',
					'Texts' => 'texts',
					'Lifehacks' => 'lifehacks',
					'Podcasts' => 'podcasts',
				],
			],
		],
	];

	public function collectData() {
		$find_tags = false;

		$src = 'https://babel.ua';

		switch ($this->getInput('language')) {
			case 'en':
				$src .= '/en';
				break;
		}

		switch ($this->getInput('content')) {
			case 'news':
				$src .= '/news';
				$find_tags = true;
				break;
			case 'texts':
				$src .= '/texts';
				break;
			case 'lifehacks':
				$src .= '/profit';
				break;
			case 'podcasts':
				$src .= '/podcasts';
				break;
		}

		$dom = getSimpleHTMLDOM($src);

		foreach ($dom->find('article.c-entry') as $article) {
			$title_dom = $article->find('h3.c-entry-title', 0);
			$title_strong_dom = $title_dom->find('strong', 0);
			if ($title_strong_dom) {
				$title = $title_strong_dom->plaintext;
			} else {
				$title = $title_dom->plaintext;
			}

			$uri = $article->find('a.c-entry-url', 0)->href;
			$timestamp = $article->find('dl.c-entry-data dd time', 0)->datetime;
			$author = $article->find('dl.c-entry-data dd b', 0)->plaintext;

			$content_dom = getSimpleHTMLDOMCached($uri);
			$content = trim($content_dom->find('article div div div div.c-post-group', 0)->innertext);

			$tags = array();
			if ($find_tags)
				foreach ($content_dom->find('dl.c-post-dl.c-post-dl-multi dd') as $tag)
					$tags[] = $tag->find('a', 0)->plaintext;

			$images = array();
			$images[] = $article->find('picture.c-entry-img-box img.c-entry-img', 0)->src;

			preg_match("/\/([0-9]+)\-/", $uri, $matches);
			$uid = $matches[1];

			$item = array();

			$item['title'] = $title;
			$item['uri'] = $uri;
			$item['timestamp'] = $timestamp;
			$item['author'] = $author;
			$item['content'] = $content;
			if ($find_tags)
				$item['categories'] = $tags;
			$item['enclosures'] = $images;
			$item['uid'] = $uid;

			$this->items[] = $item;
		}
	}
}

